import os

def main():
    source(findFile("scripts", "skrooge_functions.py"))
    initSimple()
    
    inportFile(os.getenv('IN')+"/skgtestimportofx/ofx_spec160_stmtrs_example.ofx")
    inportFile(os.getenv('IN')+"/skgtestimportcsv/bankperfect.csv")
    inportFile(os.getenv('IN')+"/skgtestimportqif/E0269787.qif")
    inportFile(os.getenv('IN')+"/skgtestimportcsvunit/test2.csv")
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+1>")
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+2>")
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Ctrl+3>")
    
    bookmarkAndRemoveCurrentPage()
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Right>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Return>")
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Right>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Up>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Return>")
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Right>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Processing_KMenu")
    type(":Untitled [modified] - skrooge.Processing_KMenu", "<Return>")
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Meta+V>")
    
    bookmarkAndRemoveCurrentPage()
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Right>")
    waitForObject(":Untitled [modified] - skrooge.Export_KMenu")
    type(":Untitled [modified] - skrooge.Export_KMenu", "<Return>")
    
    waitForObject(":Name:_KUrlComboBox_2")
    type(":Name:_KUrlComboBox_2", os.getenv('OUT')+"/tmp.csv")
    waitForObject(":Name:_KUrlComboBox_2")    
    type(":Name:_KUrlComboBox_2", "<Return>")
    
    snooze(5)
    
    waitForObject(":Untitled [modified] - skrooge_KTabBar")
    type(":Untitled [modified] - skrooge_KTabBar", "<Alt+F>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.File_KMenu")
    type(":Untitled [modified] - skrooge.File_KMenu", "<Right>")
    waitForObject(":Untitled [modified] - skrooge.Export_KMenu")
    type(":Untitled [modified] - skrooge.Export_KMenu", "<Down>")
    waitForObject(":Untitled [modified] - skrooge.Export_KMenu")
    type(":Untitled [modified] - skrooge.Export_KMenu", "<Return>")
    waitForObject(":Name:_KUrlComboBox_2")
    type(":Name:_KUrlComboBox_2", os.getenv('OUT')+"/tmp.qif")
    waitForObject(":Name:_KUrlComboBox_2")
    type(":Name:_KUrlComboBox_2", "<Return>")
    
    snooze(5)
    
    waitForObject(":Untitled [modified] - skrooge_SKGMainPanel")
    sendEvent("QCloseEvent", ":Untitled [modified] - skrooge_SKGMainPanel")
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
    sendEvent("QMouseEvent", ":Question – Skrooge.Do not save_KPushButton", QEvent.MouseButtonPress, 21, 9, Qt.LeftButton, 0)
    waitForObject(":Question – Skrooge.Do not save_KPushButton")
